Barycentric rational interpolation is a high-accuracy interpolation method for non-uniformly spaced samples.
Performance and Accuracy:
It requires O(N) time for construction and O(N) time for each evaluation. If the approximation order is d, the error is O(h^(d+1)).
Caveats:
This method is robust but can behave unexpectedly if the sample spacing at the endpoints is much larger than in the center.
Value
An object of class barycentric_rational_interpolator with methods:
interpolate(xi): Evaluate the interpolator at pointxi.prime(xi): Evaluate the derivative of the interpolator at pointxi.