Learn R Programming

boostmath (version 1.4.0)

cardinal_quadratic_b_spline: Cardinal Quadratic B-Spline Interpolator

Description

Constructs a cardinal quadratic B-spline interpolator given control points.

Usage

cardinal_quadratic_b_spline(
  y,
  t0,
  h,
  left_endpoint_derivative = NULL,
  right_endpoint_derivative = NULL
)

Value

An object of class cardinal_quadratic_b_spline with methods:

  • interpolate(xi): Evaluate the interpolator at point xi.

  • prime(xi): Evaluate the derivative of the interpolator at point xi.

Arguments

y

Numeric vector of data points to interpolate.

t0

Numeric scalar representing the starting point of the data.

h

Numeric scalar representing the spacing between data points.

left_endpoint_derivative

Optional numeric scalar for the derivative at the left endpoint.

right_endpoint_derivative

Optional numeric scalar for the derivative at the right endpoint.

Examples

Run this code
y <- c(0, 1, 0, 1)
t0 <- 0
h <- 1
interpolator <- cardinal_quadratic_b_spline(y, t0, h)
xi <- 0.5
interpolator$interpolate(xi)
interpolator$prime(xi)

Run the code above in your browser using DataLab