The cubic Hermite interpolant takes non-equispaced data and interpolates between them via cubic Hermite polynomials whose slopes must be provided.
Applications:
The interpolant is C1 and evaluation has O(log N) complexity. This interpolator is useful for solution skeletons of ODE steppers.
Value
An object of class cubic_hermite with methods:
interpolate(xi): Evaluate the interpolator at pointxi.prime(xi): Evaluate the derivative of the interpolator at pointxi.push_back(x, y, dydx): Add a new control point to the interpolator.domain(): Get the domain of the interpolator.