Functions to compute various exponential integrals, including En and Ei.
Exponential Integral En:
Defined by the integral: $$E_n(z) = \int_1^\infty \frac{e^{-zt}}{t^n} dt$$
Exponential Integral Ei:
Defined by the integral: $$Ei(z) = -\int_{-z}^\infty \frac{e^{-t}}{t} dt$$
See also
Boost Documentation for more details on the mathematical background.