Computes Owen's T function T(h, a), which gives the probability of the event (X > h and 0 < Y < a*X) where X and Y are independent standard normal random variables.
$$T(h,a)=\frac{1}{2\pi}\int_{0}^{a}\frac{\exp\!\left\{-\tfrac{1}{2}h^{2}(1+x^{2})\right\}}{1+x^{2}}\,dx,\quad (-\infty<h,a<+\infty)$$
See also
Boost Documentation for more details on the mathematical background.